@@ -1,6 +1,7 @@
 import typing
 from nikel_py.utils._constants import FOOD_BASE_URL
 from nikel_py.utils._getter import _get, _async_get
+from dateutil import parser
 
 
 class Food:
@@ -21,7 +22,7 @@ class Food:
         self.twitter = response["twitter"]
         self.facebook = response["facebook"]
         self.attributes = response["attributes"]
-        self.last_updated = response["last_updated"]
+        self.last_updated = parser.parse(response["last_updated"])
 
 
 
